%bcond_with opt
%if %{with opt}
%define _prefix /opt
%define __cmake cmake
%endif

# unpack_module_source():
# we check if we should build a given package
# if so, we unpack sources and add entry to config
# %1 - source number
# %2 - subpackage name

%define unpack_module_source() \
%if %{with %2}\
%setup -q -D -T -a %1 -n kadu-%{version}/modules\
sed "s#^module_%2=.#module_%2=m#" -i ../.config\
%endif\
%nil

# enable_module():
# enable these internal modules which are not
# enabled by default

%define enable_module() \
sed "s#^module_%1=.#module_%1=m#" -i ./.config\
%nil

%define disable_module() \
sed "s#^module_%1=.#module_%1=n#" -i ./.config\
%nil

# module_files():
# both internal and external modules have at least their .so, .ui,
# .desc and .qm files. In order to simplify things, this macro 
# creates a simple %files section
# %1 - module/subpackage name
# if parameter -d is specified, module owns its data dir
# 
# all modules have very similar directory and files structure, so
# this macro is created to make it possible to simplify %files
# sections. All modules have .desc and .so files, a lot of them
# has configurations and translations or data dirs. We use 
# respectively -c, -t and -d parameters to know which files
# a module owns.

%define module_files(d,c,t) \
%{_libdir}/kadu/modules/lib%{1}.so\
%{_datadir}/kadu/modules/%1.desc\
%if "%{-c}" \
%{_datadir}/kadu/modules/configuration/%1.ui\
%endif\
%if "%{-t}" \
%{_datadir}/kadu/modules/translations/%{1}*.qm\
%endif\
%if "%{-d}" \
%{_datadir}/kadu/modules/data/%1\
%endif\
%nil

# kadu.spec
# table to make it possible to find out quickly which
# subpackage has which source's number
# LAST NUMBER: 122
# 117 anonymous_check
# 102 globalhotkeys
# 104 led_notify
# 112 mime_tex
# 121 nextinfo
# 114 panelkadu
# 103 senthistory
# 122 splitmessages
#
# Full list of external modules below
# anonymous_check - Not available right now
# globalhotkeys 
# led_notify
# mime_tex - Not available right now
# panelkadu
# senthistory
# splitmessages


# whether we want to build certain subpackages or not
# some of them are disabled by default due to
# not being adjusted to kadu-0.6.5
%bcond_without globalhotkeys
%bcond_without lednotify
%bcond_without nextinfo
%bcond_without panelkadu
%bcond_without senthistory
%bcond_without splitmessages


%if ! %{with opt}
Name:		kadu
%else
Name:		kadu_opt
%endif
Version:	0.9.0
Release:	2%{?dist}
Summary:	An Gadu-Gadu client for online messaging
Summary(pl):	Klient Gadu-Gadu
Group:		Applications/Internet
License:	GPLv2+
URL:		http://www.kadu.net
Source0:	http://kadu.net/download/stable/kadu-%{version}.tar.bz2

# external modules:
%if %{with globalhotkeys}
Source102:      http://www.ultr.pl/kadu/globalhotkeys-0.9.0-23.tar.gz 
%endif
%if %{with lednotify}
Source104:      http://www.ultr.pl/kadu/lednotify-0.9.0-28.tar.gz 
%endif
%if %{with nextinfo}
Source121:      http://www.ultr.pl/kadu/nextinfo-0.9.0-5.tar.gz 
%endif
%if %{with panelkadu}
Source114:      http://www.ultr.pl/kadu/panelkadu-0.9.0-7.tar.gz
%endif
%if %{with senthistory}
Source103:      http://www.ultr.pl/kadu/senthistory-0.9.0-7.tar.gz
%endif
%if %{with splitmessages}
Source122:      http://www.ultr.pl/kadu/splitmessages-0.9.0-rc1.tar.gz
%endif



BuildRoot:	%{_tmppath}/%{name}
# -%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:  cmake >= 2.6.0
BuildRequires:  aspell-devel
BuildRequires:	libpng-devel libsndfile-devel openssl-devel
BuildRequires:	qt-devel >= 4.6.0
BuildRequires:	libgadu-devel >= 1.10.0
BuildRequires:	gsm-devel
BuildRequires:  desktop-file-utils
BuildRequires:	enchant-devel alsa-lib-devel
BuildRequires:	libao-devel
BuildRequires:  libidn-devel
BuildRequires:  phonon-devel
BuildRequires:	libXScrnSaver-devel
BuildRequires:	qca2-devel
# F-14+: qt-webkit-devel splits from qt-devel
BuildRequires:	qt4-webkit-devel
Obsoletes:	%{name}-ext_info < 0.6.0-0.1.alpha1
Obsoletes:	%{name}-iwait4u < 0.6.0-0.1.alpha1
Obsoletes:	%{name}-wmaker_docking < 0.6.0-0.1.alpha1
Obsoletes:	%{name}-arts_sound < 0.6.5-0.1.rc2 
#support for arts has been dropped, we've got qt4_sound now
Obsoletes:	%{name}-dcopexport < 0.6.5-0.1.rc2 
#dropped, there is no more DCOP in QT4
Obsoletes:	%{name}-agent < 0.6.5-2
Obsoletes:	%{name}-alsa_sound < 0.6.5-2
Provides:	%{name}-alsa_sound = %{version}-%{release}
Obsoletes:	%{name}-advanced_userlist < 0.6.0-0.1.alpha1
Provides:	%{name}-advanced_userlist = %{version}-%{release}
Obsoletes:	%{name}-amarok_mediaplayer < 0.6.5-2
Obsoletes:	%{name}-antistring < 0.6.5-2
Provides:	%{name}-antistring = %{version}-%{release}
Obsoletes:	%{name}-audacious_mediaplayer < 0.6.5-2
Obsoletes:	%{name}-exec_notify < 0.6.0-0.1.alpha1
Provides:	%{name}-exec_notify = %{version}-%{release}
Obsoletes:	%{name}-cenzor < 0.6.5-1
Provides:	%{name}-cenzor = %{version}-%{release}
Obsoletes:	%{name}-devel < 0.6.5-0.1.rc2
Obsoletes:	%{name}-ao_sound < 0.6.5-0.1.rc2
Provides:	%{name}-ao_sound = %{version}-%{release}
Obsoletes:	%{name}-autostatus < 0.6.5-0.1.rc2
Provides:	%{name}-autostatus = %{version}-%{release}
Obsoletes:	%{name}-auto_hide < 0.6.5-0.1.rc2
Provides:	%{name}-auto_hide = %{version}-%{release}
Obsoletes:	%{name}-anonymous_check < 0.9.0
Obsoletes:	%{name}-esd_sound < 0.6.5-2
Obsoletes:	%{name}-falf_mediaplayer < 0.6.5-2
Obsoletes:	%{name}-filedesc < 0.6.5-0.1.rc2
Provides:	%{name}-filedesc = %{version}-%{release}
Obsoletes:	%{name}-filtering < 0.6.5-0.1.rc2
Obsoletes:	%{name}-firewall < 0.6.5-0.1.rc2
Provides:	%{name}-firewall = %{version}-%{release}
Provides:	%{name}-imagelink = %{version}-%{release}
Obsoletes:	%{name}-last_seen < 0.6.5-0.1.rc2
Provides:	%{name}-last_seen = %{version}-%{release}
Obsoletes:	%{name}-mail < 0.9.0
Obsoletes:	%{name}-mediaplayer < 0.6.5-0.1.rc2
Obsoletes:	%{name}-mime_tex < 0.9.0
Obsoletes:	%{name}-mx610_notify < 0.6.5-2
Obsoletes:	%{name}-osd_hints < 0.6.5.4-1
Obsoletes:	%{name}-parser_extender < 0.6.5-0.1.rc2
Provides:	%{name}-parser_extender = %{version}-%{release}
Obsoletes:	%{name}-pcspeaker < 0.6.5-0.1.rc2
Provides:	%{name}-pcspeaker = %{version}-%{release}
Obsoletes:	%{name}-plus_pl_sms < 0.9.0
Obsoletes:	%{name}-powerkadu < 0.6.5.4-1
Obsoletes:	%{name}-profiles < 0.6.5
Provides:	%{name}-profiles_import = %{version}-%{release}
Obsoletes:	%{name}-screenshot < 0.6.5-1
Provides:	%{name}-screenshot = %{version}-%{release}
Provides:	%{name}-server_monitor = %{version}-%{release}
Provides:	%{name}-simpleview = %{version}-%{release}
Provides:	%{name}-single_window = %{version}-%{release}
Obsoletes:	%{name}-spellchecker < 0.6.5-1
Provides:	%{name}-spellchecker = %{version}-%{release}
Obsoletes:	%{name}-split_messages < 0.6.5.4-1
Obsoletes:	%{name}-tabs < 0.9.0
Obsoletes:	%{name}-water_notify < 0.6.5-2
Obsoletes:	%{name}-weather < 0.6.5-2
Obsoletes:	%{name}-word_fix < 0.6.5-0.1.rc2
Provides:	%{name}-word_fix = %{version}-%{release}
Obsoletes:	%{name}-xmms_mediaplayer < 0.6.5-2


%description
Kadu is a dynamically evolving instant messenger compatible with the Gadu-Gadu
protocol.

%description -l pl
Kadu to dynamicznie rozwijający się komunikator internetowy kompatybilny z
protokołem Gadu-Gadu.

%package globalhotkeys
Summary:        Global hotkeys support to Kadu
Summary(pl):    Obsługa skrótów globalnych do Kadu
Group:          Applications/Internet
License:        GPLv3+
Requires:       %{name} = %{version}-%{release}

%description globalhotkeys
Globalhotkeys is a module that adds support to global
hotkeys in Kadu.

%description globalhotkeys -l pl
Globalhotkeys to moduł dodający obsługę skrótów globalnych
w Kadu.

%package led_notify
Summary:	Notification by Scroll Lock LED
Summary(pl):	Powiadamianie diodą Scroll Lock
Group:		Applications/Internet
License:        GPLv2+
Requires:	%{name} = %{version}-%{release}

%description led_notify
Led_notify is a module for Kadu, to notify user of some events using Scroll Lock
LED.

%description led_notify -l pl
Led_notify to moduł dla Kadu umożliwiający powiadamianie użytkownika o pewnych
zdarzenia przy użyciu diody Scroll Lock.

%package nextinfo
Summary:	Additional information about your contacts
Summary(pl):	Dodatkowe informacje o Twoich znajomych
Group:		Applications/Internet
License:        GPLv2+
Requires:	%{name} = %{version}-%{release}

%description nextinfo
Module adds to Kadu a posibility of holding additional informations about your contacts. 
Name of previos similar module is ext_info, on which NextInfo is partly based.

%description nextinfo -l pl
Moduł dodaje do Kadu możliwość przechowywania dodatkowych informacji o znajomych.
Wcześniej taką funkcjonalność zapewniał moduł ext_info, na którym częściowo wzorowane jest NextInfo.


%package panelkadu
Summary:	Makes a panel from Kadu main window
Summary(pl):	Zamienia Kadu w panel na skraju ekranu
Group:          Applications/Internet
License:        GPLv3+
Requires:       %{name} = %{version}-%{release}
BuildRequires:  libXtst-devel

%description panelkadu
Panelkadu is a module to make a panel from Kadu main window.

%description panelkadu -l pl
Panelkadu to moduł zamieniający Kadu w panel na skraju ekranu.

%package senthistory
Summary:	History of sent messages in chat windows
Summary(pl):	Historia wysłanych wiadomości w oknie rozmowy
Group:		Applications/Internet
License:        GPLv3+
Requires:	%{name} = %{version}-%{release}

%description senthistory
Senthistory is a module which adds history of sent messages to
chat windows in Kadu.

%description senthistory -l pl
Senthistory to moduł, który dodaje historię wysłanych wiadomości
do okien rozmowy w Kadu.

%package splitmessages
Summary:	Automatically divides too long messages.
Summary(pl):	Moduł automatycznie dzieli za długie wiadomości.
Group:		Applications/Internet
License:        GPLv2+
Requires:	%{name} = %{version}-%{release}

%description splitmessages
Module automatically divides too long messages into smaller ones, that can be sent by one message.

%description splitmessages -l pl
Splitmessages automatycznie dzieli za długie wiadomości w krótsze, które da się przesłać do innego użytkownika. Dostarcza podobną funkcjonalność co stary moduł split_messages.




%prep
%setup -q -n kadu-%{version}
%unpack_module_source 102 globalhotkeys
%unpack_module_source 104 led_notify
%unpack_module_source 121 nextinfo
%unpack_module_source 114 panelkadu
%unpack_module_source 103 senthistory
%unpack_module_source 122 splitmessages
%setup -q -D -T -n kadu-%{version}

#external modules
%disable_module anonymous_check
%disable_module mime_tex

%enable_module globalhotkeys
%enable_module led_notify
%enable_module nextinfo
%enable_module panelkadu
%enable_module senthistory
%enable_module splitmessages

#internal modules
%enable_module alsa_sound
%enable_module amarok2_mediaplayer
%enable_module antistring
%enable_module ao_sound
%enable_module auto_hide
%enable_module autostatus
%enable_module cenzor
%enable_module filedesc
%enable_module filtering
%enable_module firewall
%enable_module gg_avatars
%enable_module last_seen
%enable_module qt4_docking
%enable_module qt4_sound
%enable_module osd_hints
%enable_module parser_extender
%enable_module pcspeaker
%enable_module powerkadu
%enable_module profiles
%enable_module screenshot
%enable_module spellchecker
%enable_module split_messages
%enable_module tabs
%enable_module word_fix

# exec_notify and ext_sound have always been standard modules
# so let's keep it this way
sed "s#^module_exec_notify=.#module_exec_notify=m#" -i .config
sed "s#^module_ext_sound=.#module_ext_sound=m#" -i .config

sed "s#^icons_glass16=.#icons_glass16=n#" -i .config
sed "s#^icons_glass22=.#icons_glass22=n#" -i .config

#amarok 1.x is long gone, don't build it
sed "s#^module_amarok1_mediaplayer=.#module_amarok1_mediaplayer=n#" -i .config

#let's not annoy users with update notifies
#and disable them

pushd kadu-core
sed "/CheckUpdates/s#true#false#" -i core/core.cpp
popd

# force the right lib path and set DETAILED_VERSION
sed 's#set (LIBDIR ${CMAKE_INSTALL_PREFIX}/lib)#set (LIBDIR %{_libdir})#' -i CMakeLists.txt
sed 's@#define DETAILED.*@#define DETAILED_VERSION "%{name}-%{version}-%{release}"@' -i kadu-config.h.cmake


%build
%{cmake} -DCMAKE_BUILD_TYPE=Debug -DCMAKE_USE_PTHREADS:BOOL=ON -DBUILD_DESCRIPTION="Fedora" .
make -k VERBOSE=1 %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
desktop-file-install --vendor fedora --delete-original \
    --dir ${RPM_BUILD_ROOT}%{_datadir}/applications	\
    $RPM_BUILD_ROOT%{_datadir}/applications/kadu.desktop


%clean
rm -rf $RPM_BUILD_ROOT


%post
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :


%postun
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi


%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files
%defattr(-,root,root,-)

%doc COPYING
%{_bindir}/kadu
%{_datadir}/applications/fedora-kadu.desktop
%{_datadir}/kadu/scripts/chat-scripts.js
%dir %{_libdir}/kadu
%dir %{_libdir}/kadu/modules
%dir %{_datadir}/kadu
%{_datadir}/kadu/syntax
%{_datadir}/kadu/AUTHORS
%{_datadir}/kadu/ChangeLog
%{_datadir}/kadu/ChangeLog.OLD-PL
%{_datadir}/kadu/COPYING
%{_datadir}/kadu/HISTORY
%{_datadir}/kadu/README
%{_datadir}/kadu/THANKS
%{_datadir}/kadu/configuration
%dir %{_datadir}/kadu/modules
%dir %{_datadir}/kadu/modules/configuration
%dir %{_datadir}/kadu/modules/data
%dir %{_datadir}/kadu/modules/translations
%dir %{_datadir}/kadu/themes
%dir %{_datadir}/kadu/themes/emoticons
%{_datadir}/kadu/themes/emoticons/penguins
%{_datadir}/kadu/themes/emoticons/tango
%dir %{_datadir}/kadu/themes/icons
%{_datadir}/kadu/themes/icons/default
%dir %{_datadir}/kadu/themes/icons/oxygen
%{_datadir}/kadu/themes/icons/oxygen/*
%dir %{_datadir}/kadu/themes/icons/glass
%{_datadir}/kadu/themes/icons/glass/*
%dir %{_datadir}/kadu/themes/sounds
%{_datadir}/kadu/themes/sounds/default
%{_datadir}/kadu/translations
%{_datadir}/icons/hicolor/*/apps/kadu.png

# internal modules:
%module_files alsa_sound -ct
%module_files amarok2_mediaplayer
%module_files antistring -cdt
%module_files ao_sound
%module_files auto_hide -ct
%module_files autoaway -ct
%module_files autoresponder -ct
%module_files autostatus -ct
%module_files cenzor -cdt
%module_files config_wizard -t
%module_files desktop_docking -ct
%module_files docking -ct
%module_files encryption_ng -t
%module_files encryption_ng_simlite 
%module_files exec_notify -t
%module_files ext_sound -ct
%module_files filedesc -ct
%module_files firewall -ct
%module_files gadu_protocol -dt
%module_files hints -ct
%module_files history -ct
%module_files history_migration
%module_files idle
%module_files imagelink -t
%module_files jabber_protocol -dt
%module_files kde_notify -ct
%module_files last_seen -t
%module_files mediaplayer -cdt
%module_files qt4_docking
%module_files qt4_docking_notify -t
%module_files qt4_sound
%module_files parser_extender -ct
%module_files pcspeaker -t
%module_files phonon_sound
%module_files profiles_import -t
%module_files screenshot -ct
%module_files server_monitor -t
%module_files simpleview -ct
%module_files single_window -ct
%module_files sms -cdt
%module_files sound -ct
%module_files spellchecker -ct
%module_files speech -ct
%module_files sql_history -t
%module_files tabs -ct
%module_files word_fix -cdt

# Manual module_files add because off different names of files *.ui of some modules
%{_datadir}/kadu/modules/configuration/encryption-ng.ui
%{_datadir}/kadu/modules/configuration/hint-over-user.ui
%{_datadir}/kadu/modules/configuration/hints-advanced.ui
%{_datadir}/kadu/modules/configuration/hints-notifier.ui
%{_datadir}/kadu/modules/configuration/image-link.ui
%{_datadir}/kadu/modules/configuration/qt4-docking-notify.ui
%{_datadir}/kadu/modules/configuration/server-monitor.ui
%{_datadir}/kadu/modules/configuration/serverslist.txt

# external modules:
%files globalhotkeys
%defattr(-, root, root, -)
%module_files globalhotkeys -ct

%files led_notify
%defattr(-, root, root, -)


%files nextinfo
%defattr(-, root, root, -)
%module_files nextinfo -ct

%files panelkadu
%defattr(-, root, root, -)
%module_files panelkadu -ct


%files senthistory
%defattr(-, root, root, -)
%module_files senthistory -ct

%files splitmessages
%defattr(-, root, root, -)
%module_files splitmessages -ct

%changelog
* Wed Apr 13 2011 Radoslaw Lisowski <radoslaw.lisowski@gmail.com> - 0.9.0-2
- Resolving problem (Obsoletes/Provides) with broken dependencies

* Wed Mar 30 2011 Radoslaw Lisowski <radoslaw.lisowski@gmail.com> - 0.9.0-1
- General update to version 0.9.0

* Thu Sep 02 2010 Rakesh Pandit <rakesh@fedoraproject.org> - 0.6.5.4-5
- Bump for libao/f14 branch

* Sun Aug 15 2010 Radoslaw Lisowski <radoslaw.lisowski@gmail.com> - 0.6.5.4-4
- fixing build problem with qt4-webkit-devel for f-14+

* Sun Mar 28 2010 Radoslaw Lisowski <radoslaw.lisowski@gmail.com> - 0.6.5.4-3
- Fixed URL address to plus_pl_sms module package
- Fixed modules descriptions and packages
- Removed if ... endif clauses around subpackages definitions
- Added license tags to modules: GPLv2: anonymous_check, led_notify, 
  mail, mime_text, plus_pl_sms, tabs ; GPLv3+: senthistory.

* Tue Mar 23 2010 Julian Sikorski <belegdol@fedoraproject.org> - 0.6.5.4-2
- Dropped separate sources for powerkadu, split_messages and osd_hints modules -
  they are now part of the main tarball
- Updated tabs module to 1.2.7
- Drop shipping the desktop file separately
- Added GPLv3+ License tag to panelkadu and globalhotkeys
- Dropped conditionals around subpackage definitions
- Added now explicitly needed ldflags

* Thu Mar 18 2010 Julian Sikorski <belegdol@fedoraproject.org> - 0.6.5.4-1
- Updated kadu to 0.6.5.4
- Updated modules to their latest versions
- Changed license tag to GPLv2+
- Dropped profiles and gcc44 patches
- BR enchant-devel instead of aspell-devel
- Updated the desktop file
- Added patch from SVN fixing compilation on Fedora >= 13
- Patched bogus module install paths
- Bumped BR'd libgadu version
- Dropped unnecessary %%install kludge
- Re-enabled mediaplayer module
- Dropped amarok1_mediaplayer module
- Enabled amarok2_mediaplayer and audacious_mediaplayer modules

* Fri Aug 21 2009 Tomas Mraz <tmraz@redhat.com> - 0.6.5.2-3
- rebuilt with new openssl

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.5.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri May 08 2009 Dawid Gajownik <gajownik[AT]gmail.com> - 0.6.5.2-1
- Update to 0.6.5.2
- Update kadu-gcc44.patch
- Added BuildRequires qca2-devel and libXScrnSaver-devel
- Updated globalhotkeys, mime_tex, osd_hints, panelkadu, powerkadu,
  senthistory and tabs modules
- Package idle and gg_avatars modules
- Handle properly icons
- Add kadu-profiles-fix.patch

* Fri Apr 24 2009 Milos Jakubicek <xjakub@fi.muni.cz> - 0.6.5-10
- Fix FTBFS: added kadu-gcc44.patch

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.5-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Jan 17 2009 Tomas Mraz <tmraz@redhat.com> - 0.6.5-8
- rebuild with new openssl

* Tue Dec 16 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-7
- Osd_hints tarball was missing in sources

* Tue Dec 16 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-6
- Enable kadu-osd_hints by default

* Tue Dec 16 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-5
- Fix conflicts with kadu-osd_hints and kadu-agent

* Wed Dec 10 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-4
- More cleaning

* Tue Dec 09 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-3
- Fix bz #475629

* Tue Dec 09 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-2
- Fix kadu-0.6.5 bug and install sounds to proper directory

* Wed Dec 03 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-1
- 0.6.5
- Lots of changes:
-    some modules are now considered default,
-    some others are disabled,
-    some no longer exists,
-    some changed name,
- Parameter "--with=opt" given to rpmbuild makes kadu build to
  /opt instead of /usr (useful feature in testing)
- Kadu now uses qt4
- Lots of Obsoletes/Provides to prevent breaking updates
- Etc.

* Mon May 19 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0.1-1
- 0.6.0.1
- New version of mime_tex, tabs, firewall, osd_hints, powerkadu,
audacious_mediaplayer
- New url of ao_sound
- New modules: autostatus, last_seen, globalhotkeys
- Panelkadu requires libXtst-devel to build

* Tue Apr 01 2008 Rex Dieter <rdieter@fedoraproject.org> - 0.6.0-3
- -devel: qt3-devel (f9+)

* Wed Mar 12 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-2
- Fix bugs 436574 (f8) and 436575 (f7)
- New versions of tabs and osd_hints
- New modules: anonymous_check antistring auto_hide cenzor parser_extender 
powerkadu split_messages word_fix


* Thu Feb 28 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-1
- Stable
- New versions of osd_hints, audacious_mediaplayer, filtering,
mediaplayer and panelkadu

* Mon Feb 18 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.12.rc4
- rc4
- Add modules: water_notify, osd_hints, panelkadu

* Wed Feb 13 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.11.rc3
- rc3
- New firewall module
- New versions of some modules

* Sun Feb 03 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.10.rc2.try2
- rc2-try2

* Sun Feb 03 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.9.rc2
- rc2
- New versions of led_notify, weather, pcspeaker, mime_tex, tabs,
mediaplayer, xmms_mediaplayer and mail modules
- Add filtering module
- Get rid of xmmsfix patch
- Fix mail module

* Sun Jan 13 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.8.rc1
- rc1
- New mx610_notify, falf_mediaplayer, mail and mime_tex modules.
- New versions of some modules

* Sun Jan 06 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.7.beta2
- Fix bug 427679 (add forgotten %% symbol in one place)

* Sun Jan 06 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.6.beta2
- Now forgot to include that one source changed its name

* Sun Jan 06 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.5.beta2
- Forgot to upload some sources...

* Sat Jan 05 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.4.beta2
- beta2
- Add kadu-agent

* Fri Dec 21 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.3.beta1
- 0.6.0-beta1
- Changes of almost everything, spec file has been completely rewritten
- Get rid of stupid macros including %%{_kadudir} and %%{_modtrans}
- Make it possible to build any subpackages whoever wants, no need to build
all
- Add Polish descriptions to all subpackages and change English ones
- There are too many changes to list all of them ;-)
- Hope it's now much more readable and user-friendly

* Wed Dec 19 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.2.alpha2
- 0.6.0-alpha2
- New pcspeaker module
- New version of miastoplusa_sms, profiles, dcopexport

* Sat Dec 01 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.1.alpha1
- 0.6.0-alpha1
- remove xmms, amarok, mail, extinfo, iwait4u, powerkadu, advanced_userlist, osd_hints, screenshot, firewall, filedesc
- update spellchecker, weather, dcopexport, miastopolusa_sms, tabs, led_notify, filtering
- get rid of tabs patch
- add filedesc, spellchecker and firewall patches
- exec_notify is now built-in

* Fri Aug 24 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-4
- Fix desktop file

* Fri Aug 24 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-3
- BuildID rebuild
- Fix License tag

* Thu Apr 05 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-2
- Own %%{_datadir}/kadu/modules/data (BZ: 233855)

* Tue Jan 02 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-1
- Finally a stable release

* Mon Dec 25 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.21.rc2
- Bump to RC2

* Mon Nov 14 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.20.rc1
- Add advanced_userlist, osd_hints and screenshot modules

* Wed Nov 08 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.19.rc1
- Update kadu to RC1
- Update ext_info module to 2.0beta9
- Update powerkadu module to 20061026
- Update xmms module to 1.32
- Update amarok module to 1.19
- Amarok builds on all architectures again
- Add tabs patch

* Thu Nov 02 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.18.20060915svn
- Come back to 20060915

* Sun Oct 29 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.17.20061029svn
- Disabling kadu-amarok on ppc arch

* Sun Oct 29 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.16.20061029svn
- Bump cvs snapshot to 20061029

* Tue Oct 10 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.15.20060915svn
- Another fix to not rebuilding kadu-amarok

* Sat Oct 07 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.14.20060915svn
- It really shoud work now

* Sat Oct 07 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.13.20060915svn
- It should work now

* Fri Oct 06 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.12.20060915svn
- Yet another fix...

* Fri Oct 06 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.11.20060915svn
- Rpmbuild build error workaround.

* Fri Oct 06 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.10.20060915svn
- Not rebuilding kadu-amarok on some archs

* Sat Sep 16 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.9.20060915svn
- Update upstream to 20060915
- Move themes to external spec file
- Link to existing libgadu

* Mon Sep 04 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.8.20006808svn
- FC6 rebuild

* Fri Aug 11 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.7.20060808svn
- Update upstream to 20060808
- Add firewall and wmaker_docking modules

* Sun Jul 30 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.6.20060730svn
- Update upstream do 20060730, with fixed x64 bugs
- Add mail module and emots theme

* Thu Jul 27 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.5.20060727svn
- Delete qt dependency
- Exclude libgadu.a file
- Add powerkadu, filtering and profiles modules

* Mon Jul 24 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.4.20060716svn
- Add COPYING file to doc

* Sun Jul 23 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.3.20060716svn
- Yet another fix permissions of .so files

* Sun Jul 23 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.2.20060716svn
- Fix Source0 address
- Fix permissions of .so files
- Remove libsndfile require
- Fix some descriptions of subpackages
- Add --enable-debug and --disable-dependency-tracking options to configure

* Thu Jul 20 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.1.20060716svn
- Another first release


